==> typegram-0.0.1-py3-none-any.whl: typegram/api/functions/account/updateBusinessWorkHours.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram.api import ayiin, functions
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class UpdateBusinessWorkHours(Object):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``181``
        - ID: ``4B00E066``

business_work_hours (:obj:`BusinessWorkHours<typegram.api.ayiin.BusinessWorkHours>`, *optional*):
                    N/A
                
    Returns:
        ``bool``
    """

    __slots__: List[str] = ["business_work_hours"]

    ID = 0x4b00e066
    QUALNAME = "functions.functions.Bool"

    def __init__(self, *, business_work_hours: "ayiin.BusinessWorkHours" = None) -> None:
        
                self.business_work_hours = business_work_hours  # BusinessWorkHours

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "UpdateBusinessWorkHours":
        
        flags = Int.read(b)
        
        business_work_hours = Object.read(b) if flags & (1 << 0) else None
        
        return UpdateBusinessWorkHours(business_work_hours=business_work_hours)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        
        b.write(Int(flags))
        
        if self.business_work_hours is not None:
            b.write(self.business_work_hours.write())
        
        return b.getvalue()

==> typegram-0.0.2-py3-none-any.whl: typegram/api/functions/account/updateBusinessWorkHours.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram import api
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class UpdateBusinessWorkHours(Object):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``181``
        - ID: ``4B00E066``

business_work_hours (:obj:`BusinessWorkHours<typegram.api.ayiin.BusinessWorkHours>`, *optional*):
                    N/A
                
    Returns:
        ``bool``
    """

    __slots__: List[str] = ["business_work_hours"]

    ID = 0x4b00e066
    QUALNAME = "functions.account.updateBusinessWorkHours"

    def __init__(self, *, business_work_hours: "api.ayiin.BusinessWorkHours" = None) -> None:
        
                self.business_work_hours = business_work_hours  # BusinessWorkHours

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "UpdateBusinessWorkHours":
        
        flags = Int.read(b)
        
        business_work_hours = Object.read(b) if flags & (1 << 0) else None
        
        return UpdateBusinessWorkHours(business_work_hours=business_work_hours)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        
        b.write(Int(flags))
        
        if self.business_work_hours is not None:
            b.write(self.business_work_hours.write())
        
        return b.getvalue()
